@@ -1,11 +1,19 @@
-from typing import Optional
+__all__ = (
+    "TelegramError",
+    "MigrateToChat",
+    "RetryAfter",
+    "BadGateway",
+    "RestartingTelegram",
+    "BotBlocked",
+    "BotKicked",
+)
 
 
 class TelegramError(Exception):
-    pattern: Optional[str] = None
+    pattern: str | None = None
 
     def __init__(self, error_code: int, description: str) -> None:
-        super().__init__(f'{error_code} {description}')
+        super().__init__(f"{error_code} {description}")
         self.error_code = error_code
         self.description = description
 
@@ -15,9 +23,9 @@ class TelegramError(Exception):
 
 
 class MigrateToChat(TelegramError):
-
-    def __init__(self, error_code: int, description: str,
-                 chat_id: int) -> None:
+    def __init__(
+        self, error_code: int, description: str, chat_id: int
+    ) -> None:
         super().__init__(error_code, description)
         self.error_code = error_code
         self.description = description
@@ -25,9 +33,9 @@ class MigrateToChat(TelegramError):
 
 
 class RetryAfter(TelegramError):
-
-    def __init__(self, error_code: int, description: str,
-                 retry_after: int) -> None:
+    def __init__(
+        self, error_code: int, description: str, retry_after: int
+    ) -> None:
         super().__init__(error_code, description)
         self.error_code = error_code
         self.description = description
@@ -35,16 +43,16 @@ class RetryAfter(TelegramError):
 
 
 class BadGateway(TelegramError):
-    pattern = 'bad gateway'
+    pattern = "bad gateway"
 
 
 class RestartingTelegram(TelegramError):
-    pattern = 'restart'
+    pattern = "restart"
 
 
 class BotBlocked(TelegramError):
-    pattern = 'bot was blocked by the user'
+    pattern = "bot was blocked by the user"
 
 
 class BotKicked(TelegramError):
-    pattern = 'bot was kicked from a chat'
+    pattern = "bot was kicked from a chat"
