@@ -1,18 +1,26 @@
 import re
-from typing import Final, Tuple
-
-import attr
+from dataclasses import dataclass
+from typing import Final
 
 from . import Bot, FilterProtocol
 from .bot_update import BotUpdate
 from .constants import ChatType, ContentType, UpdateType
 
-__all__ = ('UpdateTypeFilter', 'StateFilter', 'CommandsFilter',
-           'ContentTypeFilter', 'MessageTextFilter', 'CallbackQueryDataFilter',
-           'PrivateChatFilter', 'GroupChatFilter', 'ORFilter', 'ANDFilter')
+__all__ = (
+    "UpdateTypeFilter",
+    "StateFilter",
+    "CommandsFilter",
+    "ContentTypeFilter",
+    "MessageTextFilter",
+    "CallbackQueryDataFilter",
+    "PrivateChatFilter",
+    "GroupChatFilter",
+    "ORFilter",
+    "ANDFilter",
+)
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class UpdateTypeFilter:
     update_type: UpdateType
 
@@ -20,7 +28,7 @@ class UpdateTypeFilter:
         return getattr(update, self.update_type.value) is not None
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class StateFilter:
     state: str
 
@@ -28,22 +36,24 @@ class StateFilter:
         return update.state == self.state
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class CommandsFilter:
-    commands: Tuple[str, ...]
+    commands: tuple[str, ...]
 
     async def check(self, _: Bot, update: BotUpdate) -> bool:
         if update.message is None or update.message.text is None:
             return False
-        if any(update.message.text.startswith(f'/{command}')
-               for command in self.commands):
+        if any(
+            update.message.text.startswith(f"/{command}")
+            for command in self.commands
+        ):
             return True
         return False
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class ContentTypeFilter:
-    content_types: Tuple[ContentType, ...]
+    content_types: tuple[ContentType, ...]
 
     async def check(self, _: Bot, update: BotUpdate) -> bool:
         if update.message is not None:
@@ -62,60 +72,68 @@ class ContentTypeFilter:
         return False
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class MessageTextFilter:
-    pattern: 're.Pattern[str]'
+    pattern: "re.Pattern[str]"
 
     async def check(self, _: Bot, update: BotUpdate) -> bool:
-        return (update.message is not None and
-                update.message.text is not None and
-                self.pattern.match(update.message.text) is not None)
+        return (
+            update.message is not None
+            and update.message.text is not None
+            and self.pattern.match(update.message.text) is not None
+        )
 
 
-@attr.s(frozen=True, auto_attribs=True)
+@dataclass(frozen=True)
 class CallbackQueryDataFilter:
-    pattern: 're.Pattern[str]'
+    pattern: "re.Pattern[str]"
 
     async def check(self, _: Bot, update: BotUpdate) -> bool:
-        return (update.callback_query is not None and
-                update.callback_query.data is not None and
-                self.pattern.match(update.callback_query.data) is not None)
+        return (
+            update.callback_query is not None
+            and update.callback_query.data is not None
+            and self.pattern.match(update.callback_query.data) is not None
+        )
 
 
-@attr.s(frozen=True)
+@dataclass(frozen=True)
 class PrivateChatFilter:
-
     async def check(self, _: Bot, update: BotUpdate) -> bool:  # noqa
-        return (update.message is not None and
-                update.message.chat is not None and
-                update.message.chat.type == ChatType.PRIVATE)
+        return (
+            update.message is not None
+            and update.message.chat is not None
+            and update.message.chat.type == ChatType.PRIVATE
+        )
 
 
-@attr.s(frozen=True)
+@dataclass(frozen=True)
 class GroupChatFilter:
-
     async def check(self, _: Bot, update: BotUpdate) -> bool:  # noqa
         group_types = (ChatType.GROUP, ChatType.SUPERGROUP)
-        return (update.message is not None and
-                update.message.chat is not None and
-                update.message.chat.type in group_types)
+        return (
+            update.message is not None
+            and update.message.chat is not None
+            and update.message.chat.type in group_types
+        )
 
 
 class ORFilter:
-
     def __init__(self, *filters: FilterProtocol) -> None:
-        self._filters: Final[Tuple[FilterProtocol, ...]] = filters
+        self._filters: Final[tuple[FilterProtocol, ...]] = filters
 
     async def check(self, bot: Bot, update: BotUpdate) -> bool:
-        return any([await _filter.check(bot, update)
-                    for _filter in self._filters])
+        for filter_item in self._filters:
+            if await filter_item.check(bot, update):
+                return True
+        return False
 
 
 class ANDFilter:
-
     def __init__(self, *filters: FilterProtocol) -> None:
-        self._filters: Final[Tuple[FilterProtocol, ...]] = filters
+        self._filters: Final[tuple[FilterProtocol, ...]] = filters
 
     async def check(self, bot: Bot, update: BotUpdate) -> bool:
-        return all([await _filter.check(bot, update)
-                    for _filter in self._filters])
+        for filter_item in self._filters:
+            if not await filter_item.check(bot, update):
+                return False
+        return True
