@@ -1,31 +1,41 @@
 import asyncio
-import json
 from contextlib import asynccontextmanager
-from functools import partial
-from typing import AsyncIterator, Final, Hashable
+from typing import Any, AsyncIterator, Final, Hashable
 from weakref import WeakValueDictionary
 
-__all__ = ('json_dumps', 'get_python_version', 'get_software', 'KeyLock')
+import msgspec.json
+from aiohttp import web
+
+__all__ = (
+    "json_dumps",
+    "get_python_version",
+    "get_software",
+    "BotKey",
+    "KeyLock",
+)
 
 
-json_dumps: Final = partial(json.dumps, ensure_ascii=False)
+def json_dumps(obj: Any) -> str:
+    return msgspec.json.encode(obj).decode()
 
 
 def get_python_version() -> str:
     from sys import version_info as version
-    return f'{version.major}.{version.minor}.{version.micro}'
+
+    return f"{version.major}.{version.minor}.{version.micro}"
 
 
 def get_software() -> str:
     from . import __version__
-    return f'Python/{get_python_version()} aiotgbot/{__version__}'
+
+    return f"Python/{get_python_version()} aiotgbot/{__version__}"
 
 
 class KeyLock:
-
     def __init__(self) -> None:
-        self._locks: ('Final[WeakValueDictionary[Hashable,'
-                      'asyncio.Lock]]') = WeakValueDictionary()
+        self._locks: (
+            "Final[WeakValueDictionary[Hashable," "asyncio.Lock]]"
+        ) = WeakValueDictionary()
 
     @asynccontextmanager
     async def resource(self, key: Hashable) -> AsyncIterator[None]:
@@ -36,3 +46,6 @@ class KeyLock:
             lock = self._locks[key]
         async with lock:
             yield
+
+
+BotKey = web.AppKey
